# Body2

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**mime** | **str** |  | [optional] 
**parts** | [**list[DatasetsuploadlargecompleteParts]**](DatasetsuploadlargecompleteParts.md) |  | [optional] 
**file_id** | **str** |  | [optional] 
**file_key** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

